Package: pharmaversesdtmjnj
Title: J&J Innovative Medicine SDTM Test Data
Version: 0.0.4
Authors@R: 
    c(
    person(given = "David", 
            family = "Munoz Tord",
            role = c("aut", "cre"),
            email = "david.munoztord@mailbox.org"),
    person(given = "Nicholas",
           family = "Masel",
           role = c("aut"),
           email = "nmasel@its.jnj.com"),
      person(given = "Joe",
           family = "Kovach",
           role = "aut",
           email = "jkovach2@its.jnj.com"),
     person("Renfei", "Mao", , "rmao6@its.jnj.com", role = c("ctb")),
     person(given = "J&J Innovative Medicine",
           role = c("cph", "fnd"))
    )
Description: A set of Study Data Tabulation Model (SDTM) datasets constructed by 
  modifying the 'pharmaversesdtm' package to meet J&J Innovative Medicine's
  standard data structure for Clinical and Statistical Programming.
Depends: R (>= 3.5.0), pharmaversesdtm (>= 1.2.0), random.cdisc.data
License: Apache License (>= 2.0)
Encoding: UTF-8
RoxygenNote: 7.3.3
LazyData: true
Language: en-US
NeedsCompilation: no
Packaged: 2026-05-07 14:45:28 UTC; DTord
Author: David Munoz Tord [aut, cre],
  Nicholas Masel [aut],
  Joe Kovach [aut],
  Renfei Mao [ctb],
  J&J Innovative Medicine [cph, fnd]
Maintainer: David Munoz Tord <david.munoztord@mailbox.org>
Repository: CRAN
Date/Publication: 2026-05-07 16:41:08 UTC
Built: R 4.6.0; ; 2026-05-07 17:19:29 UTC; unix
