#' @title ie
#'
#' @description ie modified from pharmaversesdtm
#' @source data from pharmaversesdtm.
#'
#' @format A data frame with 60 rows and 4 variables:
#' \describe{
#'  \item{STUDYID}{Study Identifier}
#'  \item{USUBJID}{Unique Subject Identifier}
#'  \item{IECAT}{IE Category}
#'  \item{IETEST}{IE Criterion Test Name}
#' }
#' @seealso \code{\link{ae}} \code{\link{ds}} \code{\link{dv}} \code{\link{ho}} \code{\link{ie}} \code{\link{mh}} \code{\link{suppho}} \code{\link{ts}}
#' @keywords datasets ie
#' @name ie
#' @examples
#'  head(data("ie"))
"ie"

