#' @title suppho
#'
#' @description suppho modified from pharmaversesdtm
#' @source data from pharmaversesdtm.
#'
#' @format A data frame with 5955 rows and 8 variables:
#' \describe{
#'  \item{STUDYID}{Study Identifier}
#'  \item{RDOMAIN}{Related Domain}
#'  \item{USUBJID}{Unique Subject Identifier}
#'  \item{IDVAR}{Identifying Variable}
#'  \item{IDVARVAL}{Identifying Variable Value}
#'  \item{QNAM}{Qualifier Variable Name}
#'  \item{QLABEL}{Qualifier Variable Label}
#'  \item{QVAL}{Qualifier Value}
#' }
#' @seealso \code{\link{ae}} \code{\link{ds}} \code{\link{dv}} \code{\link{ho}} \code{\link{ie}} \code{\link{mh}} \code{\link{suppho}} \code{\link{ts}}
#' @keywords datasets suppho
#' @name suppho
#' @examples
#'  head(data("suppho"))
"suppho"

