#' @title ts
#'
#' @description ts modified from pharmaversesdtm
#' @source data from pharmaversesdtm.
#'
#' @format A data frame with 33 rows and 6 variables:
#' \describe{
#'  \item{STUDYID}{Study Identifier}
#'  \item{DOMAIN}{Domain Abbreviation}
#'  \item{TSSEQ}{Sequence Number}
#'  \item{TSPARMCD}{Trial Summary Parameter Short Name}
#'  \item{TSPARM}{Trial Summary Parameter}
#'  \item{TSVAL}{Parameter Value}
#' }
#' @seealso \code{\link{ae}} \code{\link{ds}} \code{\link{dv}} \code{\link{ho}} \code{\link{ie}} \code{\link{mh}} \code{\link{suppho}} \code{\link{ts}}
#' @keywords datasets ts
#' @name ts
#' @examples
#'  head(data("ts"))
"ts"

