#' @title ae
#'
#' @description ae modified from pharmaversesdtm
#' @source data from pharmaversesdtm.
#'
#' @format A data frame with 1191 rows and 36 variables:
#' \describe{
#'  \item{STUDYID}{Study Identifier}
#'  \item{DOMAIN}{Domain Abbreviation}
#'  \item{USUBJID}{Unique Subject Identifier}
#'  \item{AESEQ}{Sequence Number}
#'  \item{AESPID}{Sponsor-Defined Identifier}
#'  \item{AETERM}{Reported Term for the Adverse Event}
#'  \item{AELLT}{Lowest Level Term}
#'  \item{AELLTCD}{Lowest Level Term Code}
#'  \item{AEDECOD}{Dictionary-Derived Term}
#'  \item{AEPTCD}{Preferred Term Code}
#'  \item{AEHLT}{High Level Term}
#'  \item{AEHLTCD}{High Level Term Code}
#'  \item{AEHLGT}{High Level Group Term}
#'  \item{AEHLGTCD}{High Level Group Term Code}
#'  \item{AEBODSYS}{Body System or Organ Class}
#'  \item{AEBDSYCD}{Body System or Organ Class Code}
#'  \item{AESOC}{Primary System Organ Class}
#'  \item{AESOCCD}{Primary System Organ Class Code}
#'  \item{AESEV}{Severity/Intensity}
#'  \item{AESER}{Serious Event}
#'  \item{AEACN}{Action Taken with Study Treatment}
#'  \item{AEREL}{Causality}
#'  \item{AEOUT}{Outcome of Adverse Event}
#'  \item{AESCAN}{Involves Cancer}
#'  \item{AESCONG}{Congenital Anomaly or Birth Defect}
#'  \item{AESDISAB}{Persist or Signif Disability/Incapacity}
#'  \item{AESDTH}{Results in Death}
#'  \item{AESHOSP}{Requires or Prolongs Hospitalization}
#'  \item{AESLIFE}{Is Life Threatening}
#'  \item{AESOD}{Occurred with Overdose}
#'  \item{AEDTC}{Date/Time of Collection}
#'  \item{AESTDTC}{Start Date/Time of Adverse Event}
#'  \item{AEENDTC}{End Date/Time of Adverse Event}
#'  \item{AESTDY}{Study Day of Start of Adverse Event}
#'  \item{AEENDY}{Study Day of End of Adverse Event}
#'  \item{AEENRTPT}{End Relative to Reference Time Point}
#' }
#' @seealso \code{\link{ae}} \code{\link{ds}} \code{\link{dv}} \code{\link{ho}} \code{\link{ie}} \code{\link{mh}} \code{\link{suppho}} \code{\link{ts}}
#' @keywords datasets ae
#' @name ae
#' @examples
#'  head(data("ae"))
"ae"

