% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/ie.R
\docType{data}
\name{ie}
\alias{ie}
\title{ie}
\format{
A data frame with 60 rows and 4 variables:
\describe{
\item{STUDYID}{Study Identifier}
\item{USUBJID}{Unique Subject Identifier}
\item{IECAT}{IE Category}
\item{IETEST}{IE Criterion Test Name}
}
}
\source{
data from pharmaversesdtm.
}
\usage{
ie
}
\description{
ie modified from pharmaversesdtm
}
\examples{
 head(data("ie"))
}
\seealso{
\code{\link{ae}} \code{\link{ds}} \code{\link{dv}} \code{\link{ho}} \code{\link{ie}} \code{\link{mh}} \code{\link{suppho}} \code{\link{ts}}
}
\keyword{datasets}
\keyword{ie}
