% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/ho.R
\docType{data}
\name{ho}
\alias{ho}
\title{ho}
\format{
A data frame with 1191 rows and 12 variables:
\describe{
\item{STUDYID}{Study Identifier}
\item{USUBJID}{Unique Subject Identifier}
\item{HOSEQ}{Sequence Number}
\item{HOTERM}{Healthcare Encounter Term}
\item{HOSTDTC}{Start Date/Time of Healthcare Encounter}
\item{HOSTDY}{Study Day of Start of Encounter}
\item{HOENDTC}{End Date/Time of Healthcare Encounter}
\item{HOENDY}{Study Day of End of Healthcare Encounter}
\item{HOENRTPT}{End Relative to Reference Time Point}
\item{HOENRF}{End Relative to Reference Period}
\item{HODUR}{Duration of Healthcare Encounter}
\item{HOOCCUR}{Healthcare Encounter Occurrence}
}
}
\source{
data from pharmaversesdtm.
}
\usage{
ho
}
\description{
ho modified from pharmaversesdtm
}
\examples{
 head(data("ho"))
}
\seealso{
\code{\link{ae}} \code{\link{ds}} \code{\link{dv}} \code{\link{ho}} \code{\link{ie}} \code{\link{mh}} \code{\link{suppho}} \code{\link{ts}}
}
\keyword{datasets}
\keyword{ho}
