% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/suppho.R
\docType{data}
\name{suppho}
\alias{suppho}
\title{suppho}
\format{
A data frame with 5955 rows and 8 variables:
\describe{
\item{STUDYID}{Study Identifier}
\item{RDOMAIN}{Related Domain}
\item{USUBJID}{Unique Subject Identifier}
\item{IDVAR}{Identifying Variable}
\item{IDVARVAL}{Identifying Variable Value}
\item{QNAM}{Qualifier Variable Name}
\item{QLABEL}{Qualifier Variable Label}
\item{QVAL}{Qualifier Value}
}
}
\source{
data from pharmaversesdtm.
}
\usage{
suppho
}
\description{
suppho modified from pharmaversesdtm
}
\examples{
 head(data("suppho"))
}
\seealso{
\code{\link{ae}} \code{\link{ds}} \code{\link{dv}} \code{\link{ho}} \code{\link{ie}} \code{\link{mh}} \code{\link{suppho}} \code{\link{ts}}
}
\keyword{datasets}
\keyword{suppho}
