% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/ts.R
\docType{data}
\name{ts}
\alias{ts}
\title{ts}
\format{
A data frame with 33 rows and 6 variables:
\describe{
\item{STUDYID}{Study Identifier}
\item{DOMAIN}{Domain Abbreviation}
\item{TSSEQ}{Sequence Number}
\item{TSPARMCD}{Trial Summary Parameter Short Name}
\item{TSPARM}{Trial Summary Parameter}
\item{TSVAL}{Parameter Value}
}
}
\source{
data from pharmaversesdtm.
}
\usage{
ts
}
\description{
ts modified from pharmaversesdtm
}
\examples{
 head(data("ts"))
}
\seealso{
\code{\link{ae}} \code{\link{ds}} \code{\link{dv}} \code{\link{ho}} \code{\link{ie}} \code{\link{mh}} \code{\link{suppho}} \code{\link{ts}}
}
\keyword{datasets}
\keyword{ts}
