% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/ds.R
\docType{data}
\name{ds}
\alias{ds}
\title{ds}
\format{
A data frame with 850 rows and 14 variables:
\describe{
\item{STUDYID}{Study Identifier}
\item{DOMAIN}{Domain Abbreviation}
\item{USUBJID}{Unique Subject Identifier}
\item{DSSEQ}{Sequence Number}
\item{DSSPID}{Sponsor-Defined Identifier}
\item{DSTERM}{Reported Term for the Disposition Event}
\item{DSDECOD}{Standardized Disposition Term}
\item{DSCAT}{Category for Disposition Event}
\item{VISITNUM}{Visit Number}
\item{VISIT}{Visit Name}
\item{DSDTC}{Date/Time of Collection}
\item{DSSTDTC}{Start Date/Time of Disposition Event}
\item{DSSTDY}{Study Day of Start of Disposition Event}
\item{DSSCAT}{Subcategory for Disposition Event}
}
}
\source{
data from pharmaversesdtm.
}
\usage{
ds
}
\description{
ds modified from pharmaversesdtm
}
\examples{
 head(data("ds"))
}
\seealso{
\code{\link{ae}} \code{\link{ds}} \code{\link{dv}} \code{\link{ho}} \code{\link{ie}} \code{\link{mh}} \code{\link{suppho}} \code{\link{ts}}
}
\keyword{datasets}
\keyword{ds}
