% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/pharmaversesdtmjnj-package.R
\docType{package}
\name{pharmaversesdtmjnj-package}
\alias{pharmaversesdtmjnj}
\alias{pharmaversesdtmjnj-package}
\title{pharmaversesdtmjnj: J&J Innovative Medicine SDTM Test Data}
\description{
A set of Study Data Tabulation Model (SDTM) datasets constructed by modifying the 'pharmaversesdtm' package to meet J&J Innovative Medicine's standard data structure for Clinical and Statistical Programming.
}
\author{
\strong{Maintainer}: David Munoz Tord \email{david.munoztord@mailbox.org}

Authors:
\itemize{
  \item Nicholas Masel \email{nmasel@its.jnj.com}
  \item Joe Kovach \email{jkovach2@its.jnj.com}
}

Other contributors:
\itemize{
  \item Renfei Mao \email{rmao6@its.jnj.com} [contributor]
  \item J&J Innovative Medicine [copyright holder, funder]
}

}
\concept{internal}
\keyword{internal}
