% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/mh.R
\docType{data}
\name{mh}
\alias{mh}
\title{mh}
\format{
A data frame with 1818 rows and 31 variables:
\describe{
\item{STUDYID}{Study Identifier}
\item{DOMAIN}{Domain Abbreviation}
\item{USUBJID}{Unique Subject Identifier}
\item{MHSEQ}{Sequence Number}
\item{MHSPID}{Sponsor-Defined Identifier}
\item{MHTERM}{Reported Term for the Medical History}
\item{MHLLT}{Lowest Level Term}
\item{MHDECOD}{Dictionary-Derived Term}
\item{MHHLT}{High Level Term}
\item{MHHLGT}{High Level Group Term}
\item{MHCAT}{Category for Medical History}
\item{MHBODSYS}{Body System or Organ Class}
\item{MHSEV}{Severity/Intensity}
\item{VISITNUM}{Visit Number}
\item{VISIT}{Visit Name}
\item{VISITDY}{Planned Study Day of Visit}
\item{MHDTC}{Date/Time of History Collection}
\item{MHSTDTC}{Start Date/Time of Medical History Event}
\item{MHDY}{Study Day of History Collection}
\item{MHENDTC}{End Date/Time of Medical History Event}
\item{MHPRESP}{Medical History Event Pre-Specified}
\item{MHOCCUR}{Medical History Occurrence}
\item{MHSTRTPT}{Start Relative to Reference Time Point}
\item{MHENRTPT}{End Relative to Reference Time Point}
\item{MHSTTPT}{Start Reference Time Point}
\item{MHENTPT}{End Reference Time Point}
\item{MHENRF}{End Relative to Reference Period}
\item{MHSTAT}{Completion Status}
\item{MHTOXGR}{Standard Toxicity Grade}
\item{MHSTDY}{Study Day of Start of Medical History}
\item{MHENDY}{Study Day of End of Medical History}
}
}
\source{
data from pharmaversesdtm.
}
\usage{
mh
}
\description{
mh modified from pharmaversesdtm
}
\examples{
 head(data("mh"))
}
\seealso{
\code{\link{ae}} \code{\link{ds}} \code{\link{dv}} \code{\link{ho}} \code{\link{ie}} \code{\link{mh}} \code{\link{suppho}} \code{\link{ts}}
}
\keyword{datasets}
\keyword{mh}
